#
import numpy as np
import pandas as pd

from lifelines import datasets
from rpy2.robjects import pandas2ri
from rpy2 import robjects
from rpy2.robjects.conversion import localconverter


def load_datasets():
    datasets_dict = {}
    # ==========================================================================
    data = datasets.load_larynx()
    data["entry_date"] = data["age"]
    data["time"] += data["entry_date"]
    y = data[["entry_date", "time", "death"]]
    X = data.drop(columns=y.columns.tolist())
    datasets_dict["Larynx Cancer"] = X, y
    # ==========================================================================
    data = datasets.load_lung()
    data["entry_date"] = data["age"] * 365.25
    data["time"] += data["entry_date"]
    y = data[["entry_date", "time", "status"]]
    X = data.drop(columns=y.columns.tolist())
    X = X.select_dtypes(include=np.number)
    datasets_dict["Lung Cancer"] = X, y
    # ==========================================================================
    data = datasets.load_gbsg2().dropna()
    data["death"] = 1 - data["cens"]
    data = data.drop(columns='cens', axis=1)
    data["entry_date"] = data["age"]
    data["time"] /= 365.25
    data["time"] += data["entry_date"]

    data["horTh"] = data["horTh"] == "yes"
    data["menostat"] = data["menostat"] == "Post"
    data["tgrade"] = data["tgrade"] == "III"
    y = data[["entry_date", "time", "death"]].copy()
    X = data.drop(columns=y.columns.tolist())
    X = X.astype(float).select_dtypes(include=np.number)
    datasets_dict["Breast Cancer"] = X, y
    # =========================================================================
    robjects.r("library(survival)")
    with localconverter(robjects.default_converter + pandas2ri.converter):
        data = robjects.conversion.rpy2py(robjects.r("survival::flchain"))
    data["sex"] = (data["sex"] == "F").astype(int)
    y = pd.DataFrame(index=data.index)
    data.loc[data["futime"] <= 0, "futime"] = 0.5
    y["time"] = data["futime"]/365.25 + data["age"]
    y["death"] = data["death"]
    y["entry_point"] = data["age"]
    y = y[["entry_point", "time", "death"]]
    y['death'] = y["death"].astype(int)
    X = data[["sex", "kappa", "lambda", "creatinine", "mgus"]]
    datasets_dict["FLC chain"] = X, y
    # ==========================================================================
    data = datasets.load_dd()
    data["entry_date"] = 0
    y = data[["entry_date", "duration", "observed"]]
    X = data.drop(columns=y.columns.tolist())
    X = X.select_dtypes(include=np.number)
    datasets_dict["Dictatorship \& Democracy"] = X, y
    # ==========================================================================
    data = datasets.load_rossi()
    data["entry_date"] = 0
    y = data[["entry_date", "week", "arrest"]]
    X = data.drop(columns=y.columns.tolist())
    X = X.select_dtypes(include=np.number)
    datasets_dict["Convicts"] = X, y
    # ==========================================================================
    # data = pd.concat((synthetic.X.astype(int), synthetic.Y, synthetic.L,
    #                   synthetic.R), axis=1)
    # y = data[["left_truncation", "right_censoring", "target"]]
    # X = data.drop(columns=y.columns.tolist())
    # X = X.select_dtypes(include=np.number)
    # datasets_dict["Synthetic data"] = X, y
    return datasets_dict


datasets_dict = load_datasets()
for k, data_ in datasets_dict.items():
    X, y = data_
    y.columns = ["entry_date", "time", "death"]
    pd.concat((X, y), axis=1).to_csv(f"data/{k}.txt", index=False)
